@@ -1,6 +1,6 @@
 # flake8: noqa F401
 
-from .base import Field, Schema, SchemaKey
+from .base import Field, Schema
 from .field_types import (
     DEFAULT_FIELD_TYPE,
     DEFAULT_FIELD_TYPE_CLASS,
